DotsLoaderConfig class

Dots loader customization

Constructors

DotsLoaderConfig({int count = 3, double dotSizeRatio = 0.2, double spacingRatio = 0.05, bool scaleAnimation = true})
const

Properties

count int
final
dotSizeRatio double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleAnimation bool
final
spacingRatio double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited